@@ -20,9 +20,11 @@ class ModelViewset(DynamicModelViewSet):
             strarray = applabel.split(".")
             user = self.request.user
             if user.has_perm(strarray[0] + ".change_" + strarray[1]):
-                self.rowActions.insert(0,{'label': 'Edit', 'type': 'edit'})
+                if not (len(self.rowActions) and self.rowActions[0]['type'].lower()=='edit'):
+                    self.rowActions.insert(0,{'label': 'Edit', 'type': 'edit'})
             if user.has_perm(strarray[0] + ".delete_" + strarray[1]):
-                self.rowActions.append({'label': 'Delete', 'type': 'delete'})
+                if not (len(self.rowActions) and self.rowActions[len(self.rowActions)-1]['type'].lower() == 'delete'):
+                    self.rowActions.append({'label': 'Delete', 'type': 'delete'})
             self.request.query_params.add('exclude[]','*')
             excludeFields=[]
             for col in self.columns:
